#
# spec file for package procs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'
Name:           procs
Version:        0.13.4
Release:        bp155.1.6
Summary:        A modern replacement for ps written in Rust
License:        MIT
URL:            https://github.com/dalance/procs
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  rust-packaging

%description
procs is a replacement for ps written in Rust.

%prep
%setup -qa1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
RUSTFLAGS=%{rustflags} cargo build --release

%install
RUSTFLAGS=%{rustflags} cargo install --root=%{buildroot}%{_prefix} --path .
# remove residue crate file
rm %{buildroot}%{_prefix}/.crates.toml
rm %{buildroot}%{_prefix}/.crates2.json

%files
%license LICENSE
%doc README.md
%{_bindir}/procs

%changelog
* Mon Jan 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.13.4:
  * [Added] adding sort column to inserts #396
  * [Added] docker: Respect $DOCKER_HOST #424
* Mon Jan  9 2023 Michael Vetter <mvetter@suse.com>
- Clean up changes file
- Don't autogenerate changes entries.
  They look more crypting to the user than the entries in CHANGELOG.md.
  So let's take it from there in the future.
* Tue Oct 18 2022 dead_mozay@opensuse.org
- Update to version 0.13.3:
  * release_win: pack exe in toplevel of zip
* Wed Oct  5 2022 dead_mozay@opensuse.org
- Update to version 0.13.2:
  * Add workaround for pager issue #366
* Tue Sep 20 2022 dead_mozay@opensuse.org
- Update to version 0.13.1:
  * Remove $ from code fenced examples on readme
  * Add derive Eq to some structs
  * fix some typos
* Fri Jul 29 2022 dead_mozay@opensuse.org
- Update to version 0.13.0:
  * Fix clippy
  * Add TreeSlot column #196
  * Add case sensitivity option #159
  * Use once_cell instead of lazy_static
* Wed May 25 2022 dead_mozay@opensuse.org
- Update to version 0.12.3:
  * No changelog available.
* Thu May  5 2022 dead_mozay@opensuse.org
- Update to version 0.12.2:
  * Change coverage to llvm-cov
  * Fix dead code in `--no-default-features`
  * Fix Clippy warnings
* Fri Jan 28 2022 dead_mozay@opensuse.org
- Update to version 0.12.1:
  * Add another cgroup style of docker support #236
  * Fix wrong decode of cgroup for docker #236
  * Change termbg timeout to latency based #221
  * Update tests to replace the deprecated usage of clap
  * Add android to all cfg #223
* Tue Jan 18 2022 dead_mozay@opensuse.org
- Update to version 0.12.0:
  * Fix unexpected message at piped #221
  * Replace structopt with clap
  * Update getch to update termios #223
* Fri Dec 24 2021 dead_mozay@opensuse.org
- Update to version 0.11.13:
  * Create a separate --completion-out flag
  * Write generated shell completions to stdout
* Wed Dec 15 2021 dead_mozay@opensuse.org
- Update to version 0.11.12:
  * No changelog available.
* Tue Dec 14 2021 dead_mozay@opensuse.org
- Update to version 0.11.11:
  * No changelog available.
* Wed Oct 20 2021 dead_mozay@opensuse.org
- Update to version 0.11.10:
  * Show children processes at tree mode #181
  * Fixed search failure with only option #117
  * Add MultiSlot column #180
  * address clippy lint: manual implementation of Option::map
  * Improve grammar
* Tue Jun 22 2021 dead_mozay@opensuse.org
- Update to version 0.11.9:
  * Add: Add support for floating point values in watch interval
  * Don't need separate fields for pgid and session
  * Friendlier column name
  * Add columns for process group ID and Session on linux.
* Sat May 29 2021 dead_mozay@opensuse.org
- Update to version 0.11.8:
  * Adjust get_theme timing
* Wed May 19 2021 dead_mozay@opensuse.org
- Update to version 0.11.7:
  * Disable termbg at piped/redirected #146
  * Adjust elapsed_time format
  * Remove unused import
  * Fix compile error
  * Add elapsed_time #120
  * Add completion file message #130
* Tue May 18 2021 dead_mozay@opensuse.org
- Update to version 0.11.6:
  * No changelog.
* Thu May  6 2021 dead_mozay@opensuse.org
- Update to version 0.11.5:
  * Fix infinite recursion of get_ppids #129
* Sun May  2 2021 dead_mozay@opensuse.org
- Update to version 0.11.4:
  * Suppress theme detection at each refresh of watcher mode
* Sun May  2 2021 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
